#
# Aura Engine (https://gitlab.servus.at/aura/engine)
#
# Copyright (C) 2017-now() - The Aura Engine Team.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import logging
import unittest

from aura_engine.base.config import AuraConfig
from aura_engine.base.logger import AuraLogger
from aura_engine.core.channels import (
    ChannelFactory,
    ChannelName,
    LineChannel,
    QueueChannel,
    StreamChannel,
)
from aura_engine.core.mixer import Mixer
from aura_engine.engine import EngineEventDispatcher

from .mock import PlayoutClientMock


class TestChannelFactory(unittest.TestCase):
    """
    Testing the ChannelFactory.
    """

    mixer: Mixer = None
    factory: ChannelFactory = None

    def setUp(self):
        config = AuraConfig.instance.config
        AuraLogger(config)
        self.logger = logging.getLogger("engine-tests")

        dispatcher = EngineEventDispatcher(engine=None)
        client = PlayoutClientMock(event_dispatcher=dispatcher)
        self.mixer = client.mixer
        self.factory = ChannelFactory(self.mixer)

    def test_create_channel_load(self):
        print(self._testMethodName)

        queue_channel = self.factory.create_channel(0, ChannelName.QUEUE_A, self.mixer)
        stream_channel = self.factory.create_channel(0, ChannelName.HTTP_A, self.mixer)
        live_channel = self.factory.create_channel(0, ChannelName.LIVE_0, self.mixer)

        self.assertEqual(type(queue_channel), QueueChannel)
        self.assertEqual(type(stream_channel), StreamChannel)
        self.assertEqual(type(live_channel), LineChannel)

        queue_channel.load()
        stream_channel.load("http://foo")
        live_channel.load()


if __name__ == "__main__":
    unittest.main()
